@@ -59,6 +59,9 @@ class ChatAction(EventBuilder):
         elif isinstance(update, types.UpdateBotChatInviteRequester):
             return cls.Event(update.peer, new_join_request = update.invite, users = update.user_id)
 
+        elif isinstance(update, types.UpdatePendingJoinRequests):
+            return cls.Event(update.peer, new_approve = update.requests_pending, users = update.recent_requesters)
+
         # UpdateChannel is sent if we leave a channel, and the update._entities
         # set by _process_update would let us make some guesses. However it's
         # better not to rely on this. Rely only in MessageActionChatDeleteUser.
@@ -158,8 +161,8 @@ class ChatAction(EventBuilder):
         """
 
         def __init__(self, where, new_photo=None,
-                     added_by=None, kicked_by=None, new_join_request = None, from_approval = None, created=None,
-                     users=None, new_title=None, pin_ids=None, pin=None, new_score=None):
+                     added_by=None, kicked_by=None, new_join_request=None, from_approval=None, created=None,
+                     users=None, new_approve=None, new_title=None, pin_ids=None, pin=None, new_score=None):
             if isinstance(where, types.MessageService):
                 self.action_message = where
                 where = where.peer_id
@@ -191,6 +194,7 @@ class ChatAction(EventBuilder):
             
             self.user_approved = from_approval
             self.new_join_request = new_join_request
+            self.new_approve = new_approve
 
             # If `from_id` was not present (it's `True`) or the affected
             # user was "kicked by itself", then it left. Else it was kicked.
@@ -288,7 +292,7 @@ class ChatAction(EventBuilder):
 
             return self._pinned_messages 
 
-        async def approve_user(self, approved: bool = True):
+        async def approve_user(self, approved: bool = True, link: str = None):
             """
             Approve or disapprove chat join request of user.
             """
@@ -298,7 +302,12 @@ class ChatAction(EventBuilder):
                     user_id=self.user_id,
                     approved=approved
                 ))
-                
+            elif self.new_approve:
+                return await self.client(functions.messages.HideAllChatJoinRequestsRequest(
+                    await self.get_input_chat(),
+                    approved=approved,
+                    link = link
+                ))
         @property
         def added_by(self):
             """
